@@ -1,22 +1,20 @@
 
 #define HOST_CPU "i386"
 #define HOST_VENDOR "unknown"
-#define HOST_OS "freebsd2.2.8"
-#define HOST_OS_NAME "freebsd2"
-#define HOST_OS_VERSION "2.2.8"
+#define HOST_OS "freebsd3.0"
+#define HOST_OS_NAME "freebsd3"
+#define HOST_OS_VERSION "3.0"
 #define HOST_ARCH "i386"
-#define HOST_NAME "dingo.mcl.cs.columbia.edu"
+#define HOST_NAME "ape.mcl.cs.columbia.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Tue Jul  4 19:55:30 EDT 2000"
+#define CONFIG_DATE "Wed Feb  3 23:53:31 EST 1999"
 #define PACKAGE "am-utils"
-#define VERSION "6.0.4s6"
+#define VERSION "6.0.1s4"
 #define PACKAGE "am-utils"
-#define VERSION "6.0.4s6"
+#define VERSION "6.0.1s4"
 #define DEBUG 1
-#define HOST_HEADER_VERSION "2.2.8"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
-#define HAVE_ALLOCA 1
 #define STDC_HEADERS 1
 #define HAVE_WAIT3 1
 #define HAVE__SETERR_REPLY 1
@@ -46,7 +44,6 @@
 #define HAVE_RMDIR 1
 #define HAVE_SELECT 1
 #define HAVE_SETEUID 1
-#define HAVE_SETITIMER 1
 #define HAVE_SETSID 1
 #define HAVE_SIGACTION 1
 #define HAVE_SIGNAL 1
@@ -64,7 +61,6 @@
 #define HAVE_UNAME 1
 #define HAVE_UNMOUNT 1
 #define HAVE_VFORK 1
-#define HAVE_VSNPRINTF 1
 #define HAVE_WAIT3 1
 #define HAVE_WAITPID 1
 #define HAVE_CLNT_SPERRNO 1
@@ -117,8 +113,11 @@
 #define HAVE_SYS_WAIT_H 1
 #define HAVE_ARPA_NAMESER_H 1
 #define HAVE_ARPA_INET_H 1
+#define HAVE_ISOFS_CD9660_CD9660_MOUNT_H 1
 #define HAVE_MACHINE_ENDIAN_H 1
+#define HAVE_MSDOSFS_MSDOSFSMOUNT_H 1
 #define HAVE_NET_IF_H 1
+#define HAVE_NET_IF_VAR_H 1
 #define HAVE_NET_ROUTE_H 1
 #define HAVE_NETINET_IF_ETHER_H 1
 #define HAVE_NETINET_IN_H 1
@@ -127,6 +126,7 @@
 #define HAVE_NFS_NFSPROTO_H 1
 #define HAVE_NFS_NFSV2_H 1
 #define HAVE_NFS_RPCV2_H 1
+#define HAVE_RPC_AUTH_DES_H 1
 #define HAVE_RPC_PMAP_CLNT_H 1
 #define HAVE_RPC_PMAP_PROT_H 1
 #define HAVE_RPC_RPC_H 1
@@ -134,12 +134,13 @@
 #define HAVE_RPC_XDR_H 1
 #define HAVE_RPCSVC_MOUNT_H 1
 #define HAVE_RPCSVC_NFS_PROT_H 1
+#define HAVE_RPCSVC_NIS_H 1
 #define HAVE_RPCSVC_YP_PROT_H 1
 #define HAVE_RPCSVC_YPCLNT_H 1
-#define HAVE_SYS_DIR_H 1
 #define HAVE_SYS_ERRNO_H 1
 #define HAVE_SYS_FILE_H 1
 #define HAVE_SYS_IOCTL_H 1
+#define HAVE_SYS_LOCK_H 1
 #define HAVE_SYS_MBUF_H 1
 #define HAVE_SYS_MOUNT_H 1
 #define HAVE_SYS_PARAM_H 1
@@ -182,24 +183,24 @@
 #define HAVE_VARARGS_H 1
 #define HAVE_UNISTD_H 1
 #define TIME_WITH_SYS_TIME 1
-#define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_freebsd2.h"
+#define HAVE_ST_RDEV 1
+#define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_freebsd3.h"
 #define HAVE_STRUCT_NFS_ARGS 1
 #define nfs_args_t struct nfs_args
 #define NFS_FH_FIELD fh
 #define am_nfs_fh nfs_fh
+#define am_nfs_fh3 nfs_fh3_freebsd3
 #define GETGROUPS_T gid_t
 #define RETSIGTYPE void
 #define HAVE_FHANDLE 1
-#define MTYPE_TYPE int
-#define MTYPE_PRINTF_TYPE "%d"
+#define MTYPE_TYPE char *
+#define MTYPE_PRINTF_TYPE "%s"
 #define YP_ORDER_OUTORDER_TYPE int
 #define RECVFROM_FROMLEN_TYPE int
 #define AUTH_CREATE_GIDLIST_TYPE gid_t
 #define SVC_IN_ARG_TYPE caddr_t
 #define cdfs_args_t struct iso_args
-#define mfs_args_t struct mfs_args
 #define pcfs_args_t struct msdosfs_args
-#define ufs_args_t struct ufs_args
 #define XDRPROC_T_TYPE xdrproc_t
 #define voidp void *
 #define HAVE_EXTERN_SYS_ERRLIST 1
@@ -207,6 +208,7 @@
 #define HAVE_EXTERN_CLNT_SPCREATEERROR 1
 #define HAVE_EXTERN_CLNT_SPERRNO 1
 #define HAVE_EXTERN_FREE 1
+#define HAVE_EXTERN_GET_MYADDRESS 1
 #define HAVE_EXTERN_GETDOMAINNAME 1
 #define HAVE_EXTERN_GETDTABLESIZE 1
 #define HAVE_EXTERN_GETHOSTNAME 1
@@ -216,14 +218,13 @@
 #define HAVE_EXTERN_MKSTEMP 1
 #define HAVE_EXTERN_SBRK 1
 #define HAVE_EXTERN_SETEUID 1
-#define HAVE_EXTERN_SETITIMER 1
 #define HAVE_EXTERN_STRCASECMP 1
 #define HAVE_EXTERN_STRDUP 1
 #define HAVE_EXTERN_STRSTR 1
 #define HAVE_EXTERN_UALARM 1
 #define HAVE_EXTERN_USLEEP 1
 #define HAVE_EXTERN_WAIT3 1
-#define HAVE_EXTERN_VSNPRINTF 1
+#define HAVE_EXTERN_XDR_OPAQUE_AUTH 1
 #define HAVE_LONG_FILE_NAMES 1
 #define HAVE_RESTARTABLE_SYSCALLS 1
 #define HAVE_FIELD_CDFS_ARGS_T_FLAGS 1
@@ -233,70 +234,71 @@
 #define HAVE_FIELD_PCFS_ARGS_T_GID 1
 #define HAVE_FIELD_PCFS_ARGS_T_MASK 1
 #define HAVE_FIELD_PCFS_ARGS_T_UID 1
-#define HAVE_FIELD_UFS_ARGS_T_FSPEC 1
+#define HAVE_FIELD_STRUCT_STATFS_F_FSTYPENAME 1
+#define HAVE_FIELD_NFS_ARGS_T_ACDIRMIN 1
+#define HAVE_FIELD_NFS_ARGS_T_ACREGMIN 1
 #define HAVE_FIELD_NFS_ARGS_T_FHSIZE 1
 #define HAVE_FIELD_NFS_ARGS_T_PROTO 1
 #define HAVE_FIELD_NFS_ARGS_T_SOTYPE 1
+#define HAVE_FIELD_NFS_ARGS_T_VERSION 1
 #define HAVE_FIELD_STRUCT_IFREQ_IFR_ADDR 1
 #define HAVE_FIELD_STRUCT_SOCKADDR_SA_LEN 1
+#define HAVE_FGETS 1
 #define HAVE_MAP_FILE 1
+#define HAVE_DBM_OPEN 1
 #define HAVE_MAP_NDBM 1
+#define HAVE_YP_GET_DEFAULT_DOMAIN 1
 #define HAVE_MAP_NIS 1
+#define HAVE_GETPWNAM 1
 #define HAVE_MAP_PASSWD 1
+#define HAVE_OPENDIR 1
 #define HAVE_MAP_UNION 1
 #define HAVE_FS_CDFS 1
-#define HAVE_FS_LOFS 1
 #define HAVE_FS_MFS 1
 #define HAVE_FS_NFS 1
+#define HAVE_FS_NFS3 1
 #define HAVE_FS_PCFS 1
-#define HAVE_FS_TFS 1
 #define HAVE_FS_UFS 1
-#define HAVE_FS_NULLFS 1
 #define HAVE_FS_UNIONFS 1
-#define HAVE_FS_UMAPFS 1
-#define HAVE_AMU_FS_AUTO 1
-#define HAVE_AMU_FS_DIRECT 1
-#define HAVE_AMU_FS_TOPLVL 1
-#define HAVE_AMU_FS_ERROR 1
-#define HAVE_AMU_FS_INHERIT 1
-#define HAVE_AMU_FS_PROGRAM 1
-#define HAVE_AMU_FS_LINK 1
-#define HAVE_AMU_FS_LINKX 1
-#define HAVE_AMU_FS_HOST 1
-#define HAVE_AMU_FS_NFSX 1
-#define HAVE_AMU_FS_NFSL 1
-#define HAVE_AMU_FS_UNION 1
-#define MOUNT_TYPE_NFS MOUNT_NFS
-#define MOUNT_TYPE_UFS MOUNT_UFS
-#define MOUNT_TYPE_CDFS MOUNT_CD9660
-#define MOUNT_TYPE_PCFS MOUNT_MSDOS
-#define MOUNT_TYPE_MFS MOUNT_MFS
-#define MOUNT_TYPE_LOFS MOUNT_LOFS
-#define MOUNT_TYPE_LFS MOUNT_LFS
-#define MOUNT_TYPE_AFS MOUNT_AFS
-#define MOUNT_TYPE_TFS MOUNT_TFS
-#define MOUNT_TYPE_NULLFS MOUNT_NULL
-#define MOUNT_TYPE_UNIONFS MOUNT_UNION
-#define MOUNT_TYPE_UMAPFS MOUNT_UMAP
+#define HAVE_AM_FS_AUTO 1
+#define HAVE_AM_FS_DIRECT 1
+#define HAVE_AM_FS_TOPLVL 1
+#define HAVE_AM_FS_ERROR 1
+#define HAVE_AM_FS_INHERIT 1
+#define HAVE_AM_FS_PROGRAM 1
+#define HAVE_AM_FS_LINK 1
+#define HAVE_AM_FS_LINKX 1
+#define HAVE_AM_FS_HOST 1
+#define HAVE_AM_FS_NFSX 1
+#define HAVE_AM_FS_NFSL 1
+#define HAVE_AM_FS_UNION 1
+#define MOUNT_TYPE_NFS "nfs"
+#define MOUNT_TYPE_NFS3 MOUNT_NFS3
+#define MOUNT_TYPE_UFS "ufs"
+#define MOUNT_TYPE_CDFS "cd9660"
+#define MOUNT_TYPE_PCFS "msdos"
+#define MOUNT_TYPE_MFS "mfs"
+#define MOUNT_TYPE_IGNORE MNT_IGNORE
+#define MOUNT_TYPE_UNIONFS MNT_UNION
 #define MNTTAB_TYPE_NFS "nfs"
+#define MNTTAB_TYPE_NFS3 "nfs3"
 #define MNTTAB_TYPE_UFS "ufs"
 #define MNTTAB_TYPE_CDFS "cd9660"
 #define MNTTAB_TYPE_PCFS "msdos"
 #define MNTTAB_TYPE_MFS "mfs"
-#define MNTTAB_TYPE_LOFS "lofs"
-#define MNTTAB_TYPE_LFS "lfs"
-#define MNTTAB_TYPE_AFS "afs"
-#define MNTTAB_TYPE_TFS "tfs"
-#define MNTTAB_TYPE_NULLFS "null"
-#define MNTTAB_TYPE_UNIONFS "union"
-#define MNTTAB_TYPE_UMAPFS "umap"
+#define MNTTAB_TYPE_UNIONFS "unionfs"
 #define MNT2_GEN_OPT_ASYNC 0x40
+#define MNT2_GEN_OPT_IGNORE 0x800000
 #define MNT2_GEN_OPT_NODEV 0x10
 #define MNT2_GEN_OPT_NOEXEC 0x4
 #define MNT2_GEN_OPT_NOSUID 0x8
 #define MNT2_GEN_OPT_QUOTA 0x2000
 #define MNT2_GEN_OPT_RDONLY 0x1
 #define MNT2_GEN_OPT_SYNCHRONOUS 0x2
+#define MNT2_NFS_OPT_ACDIRMAX 0x200000
+#define MNT2_NFS_OPT_ACDIRMIN 0x100000
+#define MNT2_NFS_OPT_ACREGMAX 0x80000
+#define MNT2_NFS_OPT_ACREGMIN 0x40000
 #define MNT2_NFS_OPT_DEADTHRESH 0x4000
 #define MNT2_NFS_OPT_DUMBTIMR 0x800
 #define MNT2_NFS_OPT_INT 0x40
@@ -312,7 +314,6 @@
 #define MNT2_NFS_OPT_SOFT 0x1
 #define MNT2_NFS_OPT_TIMEO 0x8
 #define MNT2_NFS_OPT_WSIZE 0x2
-#define MNT2_CDFS_OPT_EXTATT 0x4
-#define MNT2_CDFS_OPT_GENS 0x2
-#define MNT2_CDFS_OPT_NORRIP 0x1
 #define HIDE_MOUNT_TYPE "nfs"
+#define HAVE_GETMNTINFO 1
+#define USE_CONNECTED_NFS_SOCKETS 1
